@@ -1,6 +1,6 @@
 package DBIx::Class::FormTools;
 
-use version; $VERSION = qv('0.0.1');
+our $VERSION = '0.000002';
 
 use strict;
 use warnings;
@@ -16,76 +16,104 @@ __PACKAGE__->mk_classdata('_formdata' => {});
 
 DBIx::Class::FormTools - Build forms with multiple interconnected objects.
 
-
 =head1 VERSION
 
-This document describes DBIx::Class::FormTools version 0.0.1
-
+This document describes DBIx::Class::FormTools version 0.0.2
 
 =head1 SYNOPSIS
 
+=head2 Prerequisites
+
+In the exampeles I use 3 objects, a C<Film>, a C<Actor> and a C<Role>.
+C<Role> is a many to many relation between C<Film> and C<Actor>.
+
+    package Film;
+    __PACKAGE__->has_many(roles => 'Role', 'film_id');
+    
+    package Actor;
+    __PACKAGE__->has_many(roles => 'Role', 'actor_id');
+    
+    package Role;
+    __PACKAGE__->belongs_to(film_id  => 'Film');
+    __PACKAGE__->belongs_to(actor_id => 'Actor');
+    
+
 =head2 In your Model class
 
 =over
 
     use base qw/DBIx::Class/;
-    __PACKAGE__->load_components(qw/PK::Auto::SQLite Core DB FormTools/);
+    __PACKAGE__->load_components(qw/PK::Auto::Pg Core DB FormTools/);
 
 =back
 
-=head2 In your view - Mason example
-
-
-=over
+=head2 In your view - L<HTML::Mason> example
 
     <%init>
-    my $o = Film->retrieve(42);
+    my $film  = Film->retrieve(42);
+    my $actor = Film->retrieve(24);
     </%init>
     <form>
-        <input name="<% $film->form_fieldname('title', 'o1') => 'Title' %>" type="text" value="<% $o-> %>" />
-        <input name="<% $film->form_fieldname('length', 'o1') %>" type="text" value="<% $o->length %>" />
-        <input name="<% $film->form_fieldname('comment', 'o1') %>" type="text" value="<% $o->comment %>" />
-        <input name="<% Role->form_fieldname(undef,'o3', { film_id => 'o1', actor_id => 'o2' }) %>" type="text" value="Pirate" />
-        <input name="<% $actor->form_fieldname('name', 'o2') %>" type="text" value="<% $o->name %>" />
+        <input name="<% $film->form_fieldname('title', 'o1') => 'Title' %>" type="text" value="<% $film->title %>" />
+        <input name="<% $film->form_fieldname('length', 'o1') %>" type="text" value="<% $film->length %>" />
+        <input name="<% $film->form_fieldname('comment', 'o1') %>" type="text" value="<% $film->comment %>" />
+        <input name="<% $actor->form_fieldname('name', 'o2') %>" type="text" value="<% $actor->name %>" />
+        <input name="<% Role->form_fieldname(undef,'o3', { film_id => 'o1', actor_id => 'o2' }) %>" type="hidden" value="dummy" />
     </form>
 
-=back
 
+=head2 In your controller (or cool helper module, used in your controller)
 
-=head2 In your controler
-
-    my @objects = Class::DBI::FormTools->formdata_to_objects($quesrstring);
+    my @objects = Class::DBI::FormTools->formdata_to_objects($querystring);
     foreach my $object ( @objects ) {
+        # Assert and Manupulate $object as you like
         $object->insert_or_update;
     }
 
 =head1 DESCRIPTION
 
-DBIx::Class::FormTools is a data serializer, that can convert HTML formdata to DBIx::Class objects.
+=head2 Introduction
 
-It uses usersupplied object ids to connect the objects, even if the objects does not exist on beforehand.
+C<DBIx::Class::FormTools> is a data serializer, that can convert HTML formdata to C<DBIx::Class> objects based on element names created with  C<DBIx::Class::FormTools>.
+
+It uses user supplied object ids to connect the objects with each-other. The objects does not need to exist on beforehand.
+
+The module is not ment to be used directly, although it can of-course be done as seen in the above example, but rather used as a utility module in a C<Catalyst::Helper> module or other equivalent framework.
+
+=head2 Connecting the dots - The problem at hand
+
+Creating a form with data from one object and storing it in a database is easy, and several modules that does this quite well already exists on CPAN.
+
+What I am trying to accomplish here, is to allow multiple objects to be created and updated in the same form - This includes the relations between the objects i.e. "connecting the dots".
+
+=head2 Non-existent ids - Enter object_id
+
+When converting the formdata to objects, we need "something" to identity the objects by, and sometimes we also need this "something" to point to another object in the formdata to signify a relation. For this purpose we have the C<object_id> which is user definable and can be whatever you like.
 
 =head1 METHODS
 
-=over
+=head2 C<form_fieldname($accessor, $object_id, $foreign_object_ids)>
 
-=item form_fieldname($accessor, $object_id, $foreign_object_ids)
+    my $name = $film->form_fieldname('title', 'o1');
+
+Creates a unique form field name for use in an HTML form.
 
 =over
 
-=item $accessor
-The field in the object you wish to create a key for
+=item C<$accessor>
 
-=item $object_id
-A unique string identifying this object. It is this key that is used to connect the dots.
+The attribute in the object you wish to create a key for.
 
-=item $foreign_object_ids
-A HASHREF containing attribute => object_id pairs.
+=item C<$object_id>
+
+A unique string identifying a specific object.
+
+=item C<$foreign_object_ids>
+
+A HASHREF containing C<attribute =E<gt> object_id> pairs, use this to connect objects with each-other.
 
 =back
 
-Create unique form field name for use in HTML form
-
 =cut
 sub form_fieldname
 {
@@ -123,9 +151,11 @@ sub form_fieldname
 }
 
 
-=item formdata_to_objects($formdata)
+=head2 C<formdata_to_objects($formdata)>
 
-Turn formdata in the form of a HASHREF into DBIx::Class objects
+    my @objects = DBIx::Class::FormTools->formdata_to_objects($formdata);
+
+Turn formdata in the form of a C<HASHREF> into an C<ARRAY> of C<DBIx::Class> objects.
 
 =cut
 sub formdata_to_objects
@@ -278,13 +308,20 @@ sub _inflate_object
     return($object);
 }
 
-=back
-
-=cut
-
 1; # Magic true value required at end of module
 __END__
 
+=head1 CAVEATS
+
+=head2 Transactions
+
+When using this module it is prudent that you use a database that supports transactions.
+
+The reason why this is important, is that when calling C<formdata_to_objects> C<DBIx::Class::Row-E<gt>create()> is called foreach nonexistent object in order to get the C<primary key> filled in. This call to C<create> results in a SQL C<insert> statement, and might leave you with one object successfully put into the database and one that generates a syntax error - Using transactions, will allow you to examine the C<ARRAY> of objects returned from C<formdata_to_objects> before actually storing them in the database.
+
+=head2 Automatic Primary Key generation
+
+You must use on of the C<DBIx::Class::PK::Auto::*> classes, otherwise the C<formdata_to_objects> will fail when creating new objects, as it is unable to determine the value for the primary key, and therefore is unable to connect the object to any related objects in the form.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -294,39 +331,19 @@ Please report any bugs or feature requests to
 C<bug-dbix-class-formtools@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 David Jack Olrik  C<< <david@olrik.dk> >>
 
-
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, David Jack Olrik C<< <david@olrik.dk> >>. All rights reserved.
+Copyright (c) 2006, David Jack Olrik C<< <david@olrik.dk> >>.
+All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
+=head1 SEE ALSO
 
-=head1 DISCLAIMER OF WARRANTY
+L<DBIx::Class>, L<DBIx::Class::PK::Auto>
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
